#------------------------------------------------------------------------------
# Programm         : E c k e . p m
#------------------------------------------------------------------------------
# Autor            : Christian Dhl
# Erstellt         : 10. Februar 2004
# Zuletzt gendert : 01. Januar 2005
# Aufgabe          : Eckenklasse
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# Globale private Datei-Variablen:
#------------------------------------------------------------------------------
my $Debug  = 0;


#------------------------------------------------------------------------------
# Klasse           : E c k e
# abgeleitet von   : Basis
#------------------------------------------------------------------------------
# Autor            : Christian Dhl
# Beschreibung     : Eine Ecken-Klasse.
# Attribute        : x          - X-Koordinate der Ecke
#                    y          - Y-Koordinate der Ecke
#                    farbe      - Farbe der Ecke
#                    radius     - Gre der Ecke
#                    titel      - Beschriftung der Ecke
#                    gewicht    - Gewicht der Ecke
#                    titelpos   - Position der Beschreibung
#                    gewichtpos - Position des Gewichts
# Klassen-Methoden : new        - Erstellt ein Objekt dieser Klasse.
# Objekt-Methoden  : x          - Getter / Setter
#                    y          - Getter / Setter
#                    farbe      - Getter / Setter
#                    radius     - Getter / Setter
#                    titel      - Getter / Setter
#                    gewicht    - Getter / Setter
#                    titelpos   - Getter / Setter
#                    gewichtpos - Getter / Setter
#------------------------------------------------------------------------------
# 0.0.1 - 10.02.2004 - CD - erstellt
# 0.0.2 - 30.12.2004 - CD - Neue Attribute Farbe (farbe), Gre (radius),
#                           Beschriftung (titel) und Gewicht (gewicht).
# 0.0.3 - 31.12.2004 - CD - Neue Attribute Titelposition (titelpos) und Wert-
#                           position (gewichtpos).
#------------------------------------------------------------------------------
package Graph::GED::Ecke;

use strict;
use warnings;

#use Data::Dumper;


#------------------------------------------------------------------------------
# Globale ffentliche Klassen-Variablen:
#------------------------------------------------------------------------------
use base qw/Graph::GED::Basis/;


sub new {
    #--------------------------------------------------------------------------
    # Methode      : n e w
    # Klasse       : Graph::GED::Ecke
    #--------------------------------------------------------------------------
    # Autor        : Christian Dhl
    # Aufgabe      : Erzeugt eine neue Ecke.
    # Parameter    : Klasse
    # Rckgabewert : Das geblesste neue Objekt.
    #--------------------------------------------------------------------------
    # 0.0.1 - 08.02.2004 - CD - erstellt
    # 0.0.2 - 10.02.2004 - CD - Vereinfachung durch Verwendung der Klasse
    #                           Basis.
    # 0.0.3 - 30.12.2004 - CD - Neue Attribute farbe, radius, titel und
    #                           gewicht.
    # 0.0.4 - 31.12.2004 - CD - Neue Attribute titelpos und gewichtpos.
    #--------------------------------------------------------------------------

    my $self  = shift;
    my $class = (ref $self) || $self;

    #--------------------------------------------------------------------------
    # Ausgabe der Aufrufparameter:
    #--------------------------------------------------------------------------
    print "Graph::GED::Ecke::new\n",
          "\tself       = '$self'\n",
          "\tclass      = '$class'\n",
          "\tParameter  = @_\n",
          if $Debug > 1;


    #--------------------------------------------------------------------------
    # Objekt von der Basisklasse erzeugen lassen:
    #--------------------------------------------------------------------------
    $self = $class->SUPER::new();


    #--------------------------------------------------------------------------
    # Nun setzen wir noch ein paar Attribute:
    #--------------------------------------------------------------------------
    $self->x         (   -1); # X-Koordinate
    $self->y         (   -1); # Y-Koordinate
    $self->farbe     (undef); # undef : keine individuelle Farbe
    $self->radius    (undef); # -1 : keine individuelle Gre
    $self->titel     (   ''); # Beschreibung
    $self->gewicht   (undef); # Zahl oder undef fr kein Gewicht
    $self->titelpos  ( 'NW'); # Position der Beschreibung
    $self->gewichtpos( 'SO'); # Position des Gewichts


    #--------------------------------------------------------------------------
    # ... und geben das erzeugte Objekt zurck:
    #--------------------------------------------------------------------------
    return $self;

} # sub Graph::GED::Ecke::new


#------------------------------------------------------------------------------
# The getter/setter methods:
#------------------------------------------------------------------------------
sub x          { return shift->_property('x',          @_) }
sub y          { return shift->_property('y',          @_) }
sub farbe      { return shift->_property('farbe',      @_) }
sub radius     { return shift->_property('radius',     @_) }
sub titel      { return shift->_property('titel',      @_) }
sub gewicht    { return shift->_property('gewicht',    @_) }
sub titelpos   { return shift->_property('titelpos',   @_) }
sub gewichtpos { return shift->_property('gewichtpos', @_) }


return 1;

__END__

=head1 NAME

Graphen::GED::Ecke.pm - a module for a vertex of a graph ('Ecke' is the german
word for vertex).

=head1 METHODS

=head2 class methods

=over

=item C<new>

    creates a new Ecke objekt

=back

=head2 objekt methods

=over

=item C<x>

    a mixed getter/setter for the attribute 'x' - the x coordinate

=item C<y>

    a mixed getter/setter for the attribute 'y' - the x coordinate

=item C<farbe>

    Get/Set the color of the vertex.

=item C<radius>

    Get/Set the size of the vertex.

=item C<titel>

    Get/Set the description of the vertex.

=item C<gewicht>

    Get/Set the weight of the vertex.

=item C<titelpos>

    Get/Set the position of the description of the edge.


=item C<gewichtpos>

    Get/Set the position of the weight of the edge.

=back

=head1 COPYRIGHT

Copyright 2004 Christian Duehl. All rights reserved.

This library is free software. You can redistribute it and/or
modify it under the same terms as perl itself.

=cut
